@@ -41,7 +41,7 @@ Go to http://mysql-python.sourceforge.net/MySQLdb.html for further information
 """
 from __future__ import print_function
 
-from builtins import str
+#from builtins import str
 from builtins import range
 from future.utils import raise_
 import os, time, datetime, log, traceback, sys
