@@ -46,7 +46,7 @@
 from __future__ import print_function
 from builtins import filter
 from builtins import zip
-from builtins import str
+#from builtins import str
 from builtins import map
 import sys, traceback, math, random, time, imp
 from re import match, search, findall
