@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.5
+#!/usr/bin/env python
 
 #############################################################################
 ##
@@ -53,7 +53,7 @@ from future import standard_library
 
 standard_library.install_aliases()
 from builtins import map
-from builtins import str
+#from builtins import str
 from builtins import object
 
 try:
@@ -150,6 +150,17 @@ def loadModule(module, modulename=None):
 
 load_module = loadModule
 
+def getModuleName(o):
+    """
+    returns module name of an object
+    """    
+    import inspect
+    if isString(o):
+        o = locals().get(o,o)
+    o = inspect.getmodule(o)
+    return getattr(o,'__name__','')
+
+get_module_name = getModuleName
 
 def dirClasses(module, owned=False):
     v = [a for a, v in list(module.__dict__.items()) if isinstance(v, type)]
@@ -161,7 +172,6 @@ def dirClasses(module, owned=False):
 
 def getCode(obj, deep=True):
     import inspect
-
     try:
         f = inspect.getsource(obj)
         return Struct(
