@@ -44,7 +44,7 @@ Methods for Astor-like management will go to fandango.servers
 """
 from __future__ import print_function
 
-from builtins import str
+#from builtins import str
 from builtins import object
 from .methods import *
 
