@@ -33,7 +33,7 @@
 """
 from __future__ import print_function
 
-from builtins import str
+#from builtins import str
 from builtins import map
 from future.utils import raise_
 from builtins import object
