@@ -45,7 +45,7 @@ Methods for Astor-like management will go to fandango.servers
 """
 from __future__ import print_function
 
-from builtins import str
+#from builtins import str
 from builtins import map
 from .defaults import *
 from .methods import *
