@@ -46,7 +46,7 @@ Methods for Astor-like management will go to fandango.servers
 from __future__ import print_function
 
 from builtins import filter
-from builtins import str
+#from builtins import str
 from builtins import map
 import fandango.objects as objects
 from fandango.linos import get_fqdn
