@@ -1473,11 +1473,11 @@ def SubprocessMethod(obj, *args, **kwargs):
     """
     arguments (this will be extracted from kwargs):
         object : object to extract method or callable
-        method :  string or callable to get from object
-        timeout : seconds
-        callback : optional method to be called
-
-    Method for executing reader.get_attribute_values in background
+        sp_method :  string or callable to get from object
+        sp_timeout : seconds 
+        sp_callback : optional method to be called
+    
+    Method for executing reader.get_attribute_values in background 
     with a timeout (30 s by default)
 
     In fact, it allows to call any object method passed by name;
@@ -1501,18 +1501,18 @@ def SubprocessMethod(obj, *args, **kwargs):
 
     fandango.threads.SubprocessMethod(reader,
         'get_attribute_values',att,*dates,
-        timeout=10.,callback=callback)
-
+        sp_timeout=10.,callback=callback)
+    
     >> received 414131 values
     """
-    method = kwargs.pop("method", None)
-    timeout = kwargs.pop("timeout", 30.0)
-    callback = kwargs.pop("callback", None)
-
-    # Using pipe because it's faster than queue and more efficient
-    local, remote = multiprocessing.Pipe(False)
-
-    def do_it(o, m, conn, *a, **k):
+    sp_method = kwargs.pop('sp_method',None)
+    sp_timeout = kwargs.pop('sp_timeout',30.)
+    sp_callback = kwargs.pop('sp_callback',None)
+    
+    #Using pipe because it's faster than queue and more efficient
+    local,remote = multiprocessing.Pipe(False)
+    
+    def do_it(o,m,conn,*a,**k):
         try:
             if None in (o, m):
                 m = o or m
@@ -1524,16 +1524,16 @@ def SubprocessMethod(obj, *args, **kwargs):
         except Exception as e:
             traceback.print_exc()
             conn.send(e)
-
-    args = (obj, method, remote) + args
-    proc = multiprocessing.Process(target=do_it, args=args, kwargs=kwargs)
-    # print('New Process(%s)' % str(do_it))
+        
+    args = (obj,sp_method,remote)+args
+    proc = multiprocessing.Process(target=do_it,args=args,kwargs=kwargs)
+    #print('New Process(%s)' % str(do_it))
     proc.daemon = True
     proc.start()
     t0 = time.time()
     result = None
-
-    while time.time() < t0 + timeout:
+    
+    while time.time()<t0+sp_timeout:
         if local.poll():
             result = local.recv()
             break
@@ -1543,10 +1543,10 @@ def SubprocessMethod(obj, *args, **kwargs):
     print("Join Process(%s)" % str(do_it))
     proc.terminate(), proc.join()  # close process
 
-    if time.time() > t0 + timeout:
-        result = Exception("TimeOut(%s,%s)!" % (str(obj), timeout))
-    if callback:
-        callback(result)
+    if time.time() > t0 + sp_timeout:
+        result = Exception("TimeOut(%s,%s)!" % (str(obj), sp_timeout))
+    if sp_callback:
+        sp_callback(result)
     elif isinstance(result, Exception):
         raise result
 
